@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::MetaProvides;
 
-our $VERSION = '2.001002';
+our $VERSION = '2.002003';
 
 # ABSTRACT: Generating and Populating 'provides' in your META.yml
 
@@ -20,6 +20,16 @@ our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 
 
+
+
+sub register_component {
+  require Carp;
+  Carp::croak(<<"EOF");
+[MetaProvides] is merely a top level namespace, not an actual plugin.
+Perhaps you wanted [MetaProvides::Package]? or [MetaProvides::Class] for MX:Declare style packages
+EOF
+
+}
 1;
 
 __END__
@@ -34,28 +44,40 @@ Dist::Zilla::Plugin::MetaProvides - Generating and Populating 'provides' in your
 
 =head1 VERSION
 
-version 2.001002
+version 2.002003
 
 =head1 SYNOPSIS
 
-In your projects dist.ini
+This module is not intended to be used directly, but instead, one of the following sub-modules should be used in your projects dist.ini
 
-    [MetaProvides::Class]
-    inherit_version = 0    ;optional flag
-    inherit_missing = 0    ;optional flag
-    meta_noindex    = 1    ;optional flag
+The most common usage should find
 
     [MetaProvides::Package]
-    inherit_version = 0    ;optional flag
-    inherit_missing = 0    ;optional flag
-    meta_noindex    = 1    ;optional flag
 
+Sufficient for indexing traditional Perl5 modules.
+
+Advanced Usage:
+
+    ; Traditional Perl5 Modules
+    [MetaProvides::Package]
+    inherit_version = 1  ; Default
+    inherit_missing = 1  ; Default
+    meta_noindex    = 1  ; Default
+
+    ; If using MooseX::Declare style "class" keywords.
+    ; Default configuration shown
+    [MetaProvides::Class]
+    inherit_version = 1    ; Default
+    inherit_missing = 1    ; Default
+    meta_noindex    = 1    ; Default
+
+    ; Hand Constructed Provides in an external file
     [MetaProvides::FromFile]
-    inherit_version = 0     ;optional flag
-    inherit_missing = 0     ;optional flag
-    file = some_file.ini    ;mandatory flag
+    inherit_version = 1     ; Default
+    inherit_missing = 1     ; Default
+
+    file = some_file.ini    ; mandatory flag
     reader_name = Config::INI::Reader ;optional flag
-    meta_noindex    = 1     ;optional and useless flag
 
 And then in some_file.ini
 
@@ -81,6 +103,8 @@ is here to cover this problem by defining it in the metadata.
 
 =end MetaPOD::JSON
 
+=for Pod::Coverage register_component
+
 =head1 COMPONENT SUMMARY
 
 =head2 C<::Class>
@@ -219,7 +243,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2016 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
