@@ -1,11 +1,10 @@
-use 5.008;    # utf8
+use 5.006;
 use strict;
 use warnings;
-use utf8;
 
 package Dist::Zilla::Role::MetaProvider::Provider;
 
-our $VERSION = '2.001001';
+our $VERSION = '2.002003';
 
 # ABSTRACT: A Role for Metadata providers specific to the 'provider' key.
 
@@ -222,34 +221,48 @@ sub _apply_meta_noindex {
     $self->log_debug(q{no_index found in metadata, will apply rules});
   }
 
-  my $noindex = $meta->{'no_index'};
-  my ( $files, $dirs, $packages, $namespaces ) = ( [], [], [], [] );
-  $files      = $noindex->{'file'}      if exists $noindex->{'file'};
-  $dirs       = $noindex->{'dir'}       if exists $noindex->{'dir'};
-  $dirs       = $noindex->{'directory'} if exists $noindex->{'directory'};
-  $packages   = $noindex->{'package'}   if exists $noindex->{'package'};
-  $namespaces = $noindex->{'namespace'} if exists $noindex->{'namespace'};
+  my $noindex = {
 
-  for my $file ( @{$files} ) {
+    # defaults
+    file      => [],
+    package   => [],
+    namespace => [],
+    dir       => [],
+    %{ $meta->{'no_index'} },
+  };
+  $noindex->{dir} = $noindex->{directory} if exists $noindex->{directory};
+
+  for my $file ( @{ $noindex->{file} } ) {
     @items = grep { $_->file ne $file } @items;
   }
-  for my $module ( @{$packages} ) {
+  for my $module ( @{ $noindex->{'package'} } ) {
     @items = grep { $_->module ne $module } @items;
   }
-  for my $dir ( @{$dirs} ) {
+  for my $dir ( @{ $noindex->{'dir'} } ) {
     ## no critic (RegularExpressions ProhibitPunctuationVars)
     @items = grep { $_->file !~ qr{^\Q$dir\E($|/)} } @items;
   }
-  for my $namespace ( @{$namespaces} ) {
+  for my $namespace ( @{ $noindex->{'namespace'} } ) {
     ## no critic (RegularExpressions ProhibitPunctuationVars)
-    @items = grep { $_->module !~ qr{^\Q$namespace\E($|::)} } @items;
+    @items = grep { $_->module !~ qr{^\Q$namespace\E::} } @items;
   }
   return @items;
 }
 
-use Dist::Zilla::Util::ConfigDumper 0.002001 qw( config_dumper );
+around dump_config => sub {
+  my ( $orig, $self, @args ) = @_;
+  my $config = $orig->( $self, @args );
+  my $payload = $config->{ +__PACKAGE__ } = {};
 
-around dump_config => config_dumper( __PACKAGE__, { attrs => [qw( inherit_version inherit_missing meta_noindex )] } );
+  $payload->{inherit_version} = $self->inherit_version;
+  $payload->{inherit_missing} = $self->inherit_missing;
+  $payload->{meta_noindex}    = $self->meta_noindex;
+
+  $payload->{ q[$] . __PACKAGE__ . '::VERSION' } = $VERSION;
+  return $config;
+};
+
+no Moose::Role;
 
 
 
@@ -259,16 +272,42 @@ around dump_config => config_dumper( __PACKAGE__, { attrs => [qw( inherit_versio
 
 
 sub metadata {
-  my ($self) = @_;
-  my $discover = {};
-  for ( $self->provides ) {
-    $_->copy_into($discover);
+  my ($self)          = @_;
+  my $discover        = {};
+  my (%all_filenames) = map { $_->name => 1 } @{ $self->zilla->files || [] };
+  my (%missing_files);
+  my (%unmapped_modules);
+
+  for my $provide_record ( $self->provides ) {
+    my $file   = $provide_record->file;
+    my $module = $provide_record->module;
+
+    if ( not exists $all_filenames{$file} ) {
+      $missing_files{$file} = 1;
+      $self->log_debug( 'Provides entry states missing file <' . $file . '>' );
+    }
+
+    my $notional_filename = do { ( join q[/], split /::|'/sx, $module ) . '.pm' };
+    if ( $file !~ /\b\Q$notional_filename\E\z/sx ) {
+      $unmapped_modules{$module} = 1;
+      $self->log_debug( 'Provides entry for module <' . $module . '> mapped to problematic <' . $file . '> ( want: <.*/' . $notional_filename . '> )'  );
+    }
+
+    $provide_record->copy_into($discover);
+  }
+
+  ## no critic (RestrictLongStrings)
+  if ( my $nkeys = scalar keys %missing_files ) {
+    $self->log( "$nkeys provide map entries did not map to distfiles: " . join q[, ],
+      sort keys %missing_files );
+  }
+  if ( my $nkeys = scalar keys %unmapped_modules ) {
+    $self->log( "$nkeys provide map entries did not map to .pm files and may not be loadable at install time: " . join q[, ],
+      sort keys %unmapped_modules );
   }
   return { provides => $discover };
 }
 
-no Moose::Role;
-
 1;
 
 __END__
@@ -283,59 +322,7 @@ Dist::Zilla::Role::MetaProvider::Provider - A Role for Metadata providers specif
 
 =head1 VERSION
 
-version 2.001001
-
-=head1 QUICK REFERENCE
-
-  ->new(options={})
-    inherit_version => ?attr
-    inherit_missing => ?attr
-    meta_noindex    => ?attr
-
-  [>] provides
-  ->inherit_version               # Bool = 1
-  ->inherit_missing               # Bool = 1
-  ->meta_noindex                  # Bool = 1
-  ->_resolve_version( $version )  # ( 'version' , $resolved )
-                                  # ()
-  ->_try_regen_meta               # HashRef
-  ->_apply_meta_noindex( @items ) # Modified @items
-  ->dumpconfig                    # HashRef
-  ->metadata                      # { provides => ... }
-
-  -~- Dist::Zilla::Role::MetaProvider
-  [>] metadata
-
-  -~- Dist::Zilla::Role::Plugin
-  ->new(options={})
-    plugin_name => ^attr
-    zilla       => ^attr
-    logger      => ?attr
-
-  ->plugin_name                                 # Str
-  ->zilla                                       # DZil
-  ->logger                                      #
-  ->log                                         # via logger
-  ->log_debug                                   # via logger
-  ->log_fatal                                   # via logger
-  ->mvp_multivalue_args                         # ArrayRef
-  ->mvp_aliases                                 # HashRef
-  ->plugin_from_config( $name, $arg, $section ) # Instance
-  ->register_component( $name, $arg, $section );
-
-=over 4
-
-=item * C<Dist::Zilla::Role::MetaProvider> : L<<
-C<Dist::Zilla::Role::MetaProvider>
-|Dist::Zilla::Role::MetaProvider
->>
-
-=item * C<Dist::Zilla::Role::Plugin> : L<<
-C<Dist::Zilla::Role::Plugin>
-|Dist::Zilla::Role::Plugin
->>
-
-=back
+version 2.002003
 
 =head1 PUBLIC METHODS
 
@@ -495,7 +482,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric.
+This software is copyright (c) 2016 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
